{ inputs, config, lib, pkgs, ... }:
{
#home-manager.users.insert= { pkgs, ... }: {
  imports = [
    ./home-files.nix
  ];

 home.packages = [ 
    pkgs.git 
    pkgs.fluffychat
    pkgs.cinny-desktop
    pkgs.firefox
    pkgs.kate
    pkgs.godot_4
    pkgs.filezilla
    pkgs.libsForQt5.lightly 
    pkgs.pfetch 
    pkgs.git-credential-oauth 
    pkgs.wayvnc 
    pkgs.android-tools 
    pkgs.gnome.eog 
    pkgs.libsForQt5.gwenview 
    pkgs.libsForQt5.qtstyleplugins 
    pkgs.libsForQt5.qt5ct 
    pkgs.oh-my-zsh  
    pkgs.kubectl 
    pkgs.kubernetes-helm 
    pkgs.vscodium 
    #pkgs.atool 
    #pkgs.httpie 
    pkgs.webcord
    pkgs.pika-backup
    pkgs.tigervnc
    pkgs.syncthing 
    pkgs.zsh-syntax-highlighting
    pkgs.zsh-history-substring-search 
    pkgs.kitty 
    pkgs.grim 
    pkgs.slurp 
    pkgs.prismlauncher
    pkgs.glfw-wayland-minecraft
  ];
  services.syncthing.enable = true;
  
  gtk = {
      enable = true;
      iconTheme = {
        name = "Papirus-Dark";
        package = pkgs.papirus-icon-theme;
      };
      cursorTheme = {
        name = "Catppuccin-Frappe-Blue-Cursors";
        package = pkgs.catppuccin-cursors.frappeBlue;
        size = 24;
      };
      theme = {
      name = "Catppuccin-Frappe-Standard-Mauve-Dark";
      package = pkgs.catppuccin-gtk.override {
        accents = [ "mauve" ];
        size = "standard";
        #tweaks = [ "black" ];
        variant = "frappe";
      };
    };

      gtk3.extraConfig = {
      Settings = ''
        gtk-application-prefer-dark-theme=1
      '';
    };

      gtk4.extraConfig = {
      Settings = ''
        gtk-application-prefer-dark-theme=1
      '';
    };

  };
  programs.nnn = {
    enable = true;
    #plugins = { "launch", "imgview" };
    plugins.src = (pkgs.fetchFromGitHub {
                    owner = "jarun";
                    repo = "nnn";
                    rev = "v4.9";
                    sha256 = "sha256-Hpc8YaJeAzJoEi7aJ6DntH2VLkoR6ToP6tPYn3llR7k=";
                  }) + "/plugins";
   plugins.mappings = {
                        l = "launch";
                        v = "imgview";
                        g = "getplugs";
                      };

  };   

  accounts.email = {
    accounts.insert = {
      address = "insert@insertapp.net";
      gpg = {
        key = "A70775C389ACF105";
        signByDefault = true;
      };
      imap.host = "imap.purelymail.com";
      imap.port = 993;
      primary = true;
      realName = "Insert";
      smtp = {
        host = "smtp.purelymail.com";
        port = 465;
      };
      passwordCommand = "cat ${config.age.secrets.email.path}";
      userName = "insert@insertapp.net";
      #notmuch.enable = true;
      thunderbird.enable = true;
    };
  };

  #programs.notmuch.enable = true;
  programs.himalaya.enable = false;
  programs.thunderbird = {
    enable = true;
    profiles.insert = {
      #name = "Insert";
      isDefault = true;
      withExternalGnupg = false;
      settings = {"mail.openpgp.alternative_gpg_path" = "/run/current-system/sw/bin/gpg-agent";};
    };
  };

  programs.librewolf.enable = true;

  programs.git = {
    enable = true;
    userName = "insert";
    userEmail = "insert@insertapp.net";
    signing = {
      key = "A70775C389ACF105";
      signByDefault = true;
    };
  };
  programs.thefuck.enable = true;
  programs.git-credential-oauth.enable = true;
  programs.kitty = {
    enable = true;
    theme = "Catppuccin-Frappe";
    settings = {
       font_family = "Monocraft Nerd Font";
    };
  };
  programs.zsh = {
    enable = true;
    shellAliases = {
    update = "sudo nixos-rebuild switch --flake /home/insert/Documents/nixos# -v --impure --upgrade --option commit-lockfile-summary 'Update flake.lock' --commit-lock-file";
    update-locked = "sudo nixos-rebuild switch --flake /home/insert/Documents/nixos# -v --impure";
    garbage = "nix-collect-garbage";
    };
    initExtra = ''

      source ~/.p10k.zsh
      export TERM=xterm-256color
      PF_INFO="ascii title os kernel uptime pkgs memory wm de palette" pfetch

    ''; 
    plugins = [
    {name = "powerlevel10k";src = pkgs.zsh-powerlevel10k;file = "share/zsh-powerlevel10k/powerlevel10k.zsh-theme";}
    {
        name = "zsh-nix-shell";
        file = "nix-shell.plugin.zsh";
        src = pkgs.fetchFromGitHub {
          owner = "chisui";
          repo = "zsh-nix-shell";
          rev = "v0.8.0";
          sha256 = "1lzrn0n4fxfcgg65v0qhnj7wnybybqzs4adz7xsrkgmcsr0ii8b7";
        };
      }
    ]; 
    syntaxHighlighting.enable = true;
    historySubstringSearch.enable = true;
    autosuggestion.enable = true;
    oh-my-zsh = {
      enable = true;
      plugins = [ "git"  "kubectl" ];
      #theme = "powerlevel10k/powerlevel10k";
    };
  };
  home.stateVersion = "23.05";
  programs.home-manager.enable = true;
}
